@@ -4,19 +4,22 @@
 # MIT License
 # Copyright (C) Michael Tao-Yi Lee (taoyil AT UCI EDU)import sys
 import logging
+import platform
 import sys
-import termios
 import time
-import tty
 
 from uci_cbp_demo.bluetooth.callbacks import is_data
 
 logger = logging.getLogger("bp_demo")
+if platform.system() == "Linux":
+    import termios
+    import tty
 
 
 class TerminalManager:
     def __init__(self, pipe):
-        self.term_settings = termios.tcgetattr(sys.stdin)
+        if platform.system() == "Linux":
+            self.term_settings = termios.tcgetattr(sys.stdin)
         self.pipe = pipe
 
     def wait_for_connection(self):
@@ -25,9 +28,13 @@ class TerminalManager:
 
     def handle_session(self):
         self.wait_for_connection()
-        tty.setcbreak(sys.stdin.fileno())
-        while not is_data():
-            pass
+        if platform.system() == "Linux":
+            tty.setcbreak(sys.stdin.fileno())
+            while not is_data():
+                pass
+        else:
+            time.sleep(20)
         self.pipe.send("stop")
         logger.info("Restoring tty...")
-        termios.tcsetattr(sys.stdin, termios.TCSADRAIN, self.term_settings)
+        if platform.system() == "Linux":
+            termios.tcsetattr(sys.stdin, termios.TCSADRAIN, self.term_settings)
